@@ -75,7 +75,8 @@ IBM_tabul_stochasticInteg <- function(n.sim = 200, n.varCovMat = 100, sample1 =
 
   exp.comp.dist <- paste0("p", comp.dist)
   if (any(exp.comp.dist == "pmultinom")) { exp.comp.dist[which(exp.comp.dist == "pmultinom")] <- "stepfun" }
-  comp_tab <- sapply(X = exp.comp.dist, FUN = get, pos = "package:stats", mode = "function")
+#  comp_tab <- sapply(X = exp.comp.dist, FUN = get, pos = "package:stats", mode = "function")
+  comp_tab <- sapply(X = exp.comp.dist, FUN = get, mode = "function")
   for (i in 1:length(comp_tab)) assign(x = names(comp_tab)[i], value = comp_tab[[i]])
   ## Create the expression involved in future assessments of the CDF:
   make.expr.step <- function(i) paste(names(comp_tab)[i],"(x = 1:", length(comp.param[[i]][[2]]), paste(", y = ", paste("cumsum(c(0,",
